#
# spec file for package camsource
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           camsource
BuildRequires:  libjpeg-devel
BuildRequires:  libtool
BuildRequires:  libv4l-devel >= 0.8.4
BuildRequires:  pkgconfig(libxml-2.0)
Version:        0.7.1
Release:        5.2
Summary:        Camsource Grabs Images from a Video4Linux Device
License:        GPL-2.0-or-later
Group:          Amusements/Toys/Graphics
URL:            http://camsource.sourceforge.net
Source:         camsource-%{version}.tar.gz
Source1:        camsource-rpmlintrc
Patch0:         camsource-no_implicit_decls.diff
Patch1:         camsource-v4l-conf-video_window-overwrite.patch
Patch2:         camsource-fix.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Camsource grabs images from a video4linux device (webcam or TV card).
It is modular and has several plug-ins for modifying the image before
displaying it via HTTP or FTP upload.

%package devel
Summary:        Camsource Grabs Images from a Video4Linux Device
Group:          Development/Libraries/C and C++
Requires:       camsource = %{version}
Provides:       camsource:/usr/include/camsource/image.h
BuildArch:      noarch

%description devel
Camsource grabs images from a video4linux device (webcam or TV card).
It is modular and has several plug-ins for modifying the image before
displaying it via HTTP or FTP upload.

%prep
%autosetup -p1
chmod ugo+x configure

%build
export CFLAGS="%{optflags} -Wall"
%configure --disable-static --with-pic
make %{?_smp_mflags}

%install
%make_install
mv %{buildroot}%{_sysconfdir}/camsource.conf.example %{buildroot}%{_sysconfdir}/camsource.conf

%files
%defattr(-,root,root)
%license COPYING
%doc INSTALL ChangeLog camsource.conf.example
%{_bindir}/camsource
%{_libdir}/camsource
%config(noreplace) %{_sysconfdir}/camsource.conf

%files devel
%defattr(-,root,root)
%{_includedir}/camsource

%changelog
* Thu Nov  7 2024 Marcus Meissner <meissner@suse.com>
- camsource-fix.patch: fix build with new glibc
* Thu Feb 22 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
- Remove obsolete version check for 1210
- Make devel subpackage noarch
- Use %%license
* Fri Feb  7 2020 David Mair <dmair@suse.com>
- The camsource v4l1 module has logic errors opening the video
  device that incorrectly perform a channel set when a grab window
  set (frame size, fps, etc) is intended. The error handling from
  the invalid channel set causes the configuration frame size and
  fps settings to be discarded and replaced with the current
  settings active on the video device. The result is that running a
  v4l(1/2) application on a given camera before using camsource on
  the same camera means camsource has the grab window attributes
  from the other application not the one specified in camsource
  configuration
- camsource-v4l-conf-video_window-overwrite.patch
* Tue Jul  7 2015 meissner@suse.com
- updated to final 0.7.1 version
  - new automatic gamma correction
- camsource-no_implicit_decls.diff: refreshed
* Mon Dec  1 2014 meissner@suse.com
- updated to 0.7.1
  - Upgrade the internal v4l driver connection to v4l2
  - Now able to build correkt Makefile, no manuel action in this case
    required.
  - Now runs under Raspbian Wheezy in Raspberry PI!
  - Added function Browser Refresh, configurable via camsource.conf
  - Add function sharpen (source pencam-2-0.67, via "The Gimp"),
    configuarable via camsource.conf
  - Add function saturate (same source), configurable via
    camsource.conf
- dropped camsource-v4l1.patch: upstream
- dropped camsource-no_label_at_end.diff: upstream
* Tue Jan 22 2013 matwey.kornilov@gmail.com
- An alternative fix for bnc#714439, we don't need any wrappers while
  we can recompile apps from the sources
- Add camsource-v4l1.patch
- Drop camsource-v4l-2.6.38.patch
- Drop camsource-rename.patch
* Sat Jan 19 2013 mhrusecky@suse.com
- used example as a default configuration file
- added wrapper around libv4l to make it work again (bnc#714439)
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Thu Jul  7 2011 idonmez@novell.com
- Add camsource-v4l-2.6.38.patch: use new v4l interface
* Thu Mar 26 2009 crrodriguez@suse.de
- do not include static libraries
* Sat May 26 2007 ro@suse.de
- split off devel package
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 22 2005 ro@suse.de
- fix implicit declaration
* Tue Jul  5 2005 pth@suse.de
- Include standard headers where necessary.
* Mon Apr 18 2005 pth@suse.de
- Just return instead of jumping to the end of the block.
* Mon Aug 23 2004 wengel@suse.de
- removed example config file from /etc/
* Tue Jan  6 2004 adrian@suse.de
- fix build
* Thu Dec 18 2003 wengel@suse.de
- removed /etc/camsource configuration directory
* Thu Dec 18 2003 wengel@suse.de
- initial package
